ReadStream

Struct ReadStream 

pub struct ReadStream { /* private fields */ }
ReadStream is used to receive streamed data.

Implementations

Source

impl ReadStream

pub fn read_chunk(&mut self) -> Option<Result<Vec<u8>, StreamError>>

Reads a chunk of binary data from the stream.

pub fn pipe_to(&mut self, ws: &mut WriteStream) -> Result<(), StreamError>

Pipes a read stream into a write stream. After all data is transmitted, both streams are closed.

pub fn read_all(&mut self) -> Result<Vec<u8>, StreamError>

Reads and returns all data from the stream until the end of stream.

This method does not close the stream.